@@ -26,7 +26,6 @@ import gtk, gobject
 from solfege import gu
 from solfege import inputwidgets
 from solfege.specialwidgets import RandomTransposeDialog
-from solfege.exceptiondialog import ExceptionDialog
 from solfege import soundcard, mpd
 from solfege import utils
 from solfege import cfg, lessonfile, osutils, const
@@ -54,6 +53,7 @@ class Teacher(cfg.ConfigUtils, QstatusDefs):
         # The file name, not a file object
         self.m_lessonfile = None
         self.m_question = None
+        self.m_custom_mode = False
     def maybe_auto_new_question(self):
         if self.get_bool('new_question_automatically'):
             if self.m_timeout_handle is None:
@@ -98,7 +98,7 @@ class Teacher(cfg.ConfigUtils, QstatusDefs):
 """There was an IOError while trying to parse a lesson file:
 %s.""" % e)
             return
-        if [q for q in self.m_P.m_questions if isinstance(q['music'], lessonfile.Cmdline)]:
+        if [q for q in self.m_P.m_questions if isinstance(q.get('music'), lessonfile.Cmdline)]:
             run = gu.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
             if not run:
                 self.m_P = None
@@ -116,8 +116,8 @@ class MelodicIntervalTeacher(Teacher):
     """
     Base class for interval exercises where
     you can have more than one interval.
-    When this class was created it was used by melodic-intevall
-    and sing-interval.
+    When this class was created it was used by melodicinterval
+    and singinterval.
     """
     OK = 0
     ERR_PICKY = 1
@@ -280,7 +280,7 @@ class RhythmAddOnClass:
         """
         # FIXME can we use lessonfile.Rhythm insted of this?
         score = mpd.parser.parse_to_score_object(rhythm)
-        track = score.get_midi_events_as_percussion()[0]
+        track = mpd.score_to_percussion_tracks(score)[0]
         track.prepend_bpm(self.get_int("bpm"))
         track.prepend_volume(cfg.get_int('config/preferred_instrument_volume'))
         track.replace_note(mpd.notename_to_int("c"),
@@ -318,7 +318,6 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
          - practise_box
          - action_area
          - config_box
-    
     """
     short_delay=700
     def __init__(self, teacher, no_notebook=False):
@@ -487,7 +486,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
                         name = name.split('-')[0]
                     getattr(self, 'g_%s' % name).hide()
     def std_buttons_answer_correct(self):
-        # Setting sensitivity is only required when 
+        # Setting sensitivity is only required when
         # self.get_bool('config/picky_on_new_question') is True, but
         # we does it every time just in case the user have changed the
         # variable between clicking 'New' and answering the question.
@@ -607,7 +606,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         spin.set_sensitive(b.get_active())
         hbox.pack_start(spin, False)
     def _lessonfile_exception(self, exception, sourcefile, lineno):
-        m = ExceptionDialog(exception)
+        m = gu.ExceptionDialog(exception)
         idx = self.m_t.m_P._idx
         if idx is not None:
             m.add_text(_('Please check question number %(idx)i in the lesson file "%(lf)s".') % {'idx': self.m_t.m_P._idx+1, 'lf': self.m_t.m_P.m_filename})
@@ -621,7 +620,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         m.run()
         m.destroy()
     def _mpd_exception(self, exception, sourcefile, lineno):
-        m = ExceptionDialog(exception)
+        m = gu.ExceptionDialog(exception)
         if 'm_mpd_varname' in dir(exception):
             m.add_text(_('Failed to parse the music in the variable "%(varname)s" in question number %(idx)i in the lesson file "%(lf)s".') % {
                 'idx': self.m_t.m_P._idx + 1,
@@ -682,7 +681,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
             return True
         elif isinstance(e, osutils.OsUtilsException):
             cleanup_function()
-            solfege.win.display_exception_message(e)
+            gu.display_exception_message(e)
             return True
         return False
 
